# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/stats/per_possession_stats.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/stats/per_possession_stats.proto',
  package='api.stats',
  serialized_pb=_b('\n$api/stats/per_possession_stats.proto\x12\tapi.stats\"\xb9\x01\n\rAverageCounts\x12\r\n\x05pass_\x18\x01 \x01(\x02\x12\x0e\n\x06passed\x18\x02 \x01(\x02\x12\x0f\n\x07\x64ribble\x18\x03 \x01(\x02\x12\x1c\n\x14\x64ribble_continuation\x18\x04 \x01(\x02\x12\x0c\n\x04shot\x18\x05 \x01(\x02\x12\x0c\n\x04goal\x18\x06 \x01(\x02\x12\x0e\n\x06\x61ssist\x18\x07 \x01(\x02\x12\x10\n\x08\x61ssisted\x18\x08 \x01(\x02\x12\x0c\n\x04save\x18\t \x01(\x02\x12\x0e\n\x06\x61\x65rial\x18\n \x01(\x02\"\x85\x01\n\x12PerPossessionStats\x12\x30\n\x0e\x61verage_counts\x18\x01 \x01(\x0b\x32\x18.api.stats.AverageCounts\x12\x18\n\x10\x61verage_duration\x18\x02 \x01(\x02\x12\x14\n\x0c\x61verage_hits\x18\x03 \x01(\x02\x12\r\n\x05\x63ount\x18\x04 \x01(\x05')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_AVERAGECOUNTS = _descriptor.Descriptor(
  name='AverageCounts',
  full_name='api.stats.AverageCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pass_', full_name='api.stats.AverageCounts.pass_', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passed', full_name='api.stats.AverageCounts.passed', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dribble', full_name='api.stats.AverageCounts.dribble', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dribble_continuation', full_name='api.stats.AverageCounts.dribble_continuation', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shot', full_name='api.stats.AverageCounts.shot', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='goal', full_name='api.stats.AverageCounts.goal', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assist', full_name='api.stats.AverageCounts.assist', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assisted', full_name='api.stats.AverageCounts.assisted', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='save', full_name='api.stats.AverageCounts.save', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aerial', full_name='api.stats.AverageCounts.aerial', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=237,
)


_PERPOSSESSIONSTATS = _descriptor.Descriptor(
  name='PerPossessionStats',
  full_name='api.stats.PerPossessionStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='average_counts', full_name='api.stats.PerPossessionStats.average_counts', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='average_duration', full_name='api.stats.PerPossessionStats.average_duration', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='average_hits', full_name='api.stats.PerPossessionStats.average_hits', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='api.stats.PerPossessionStats.count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=373,
)

_PERPOSSESSIONSTATS.fields_by_name['average_counts'].message_type = _AVERAGECOUNTS
DESCRIPTOR.message_types_by_name['AverageCounts'] = _AVERAGECOUNTS
DESCRIPTOR.message_types_by_name['PerPossessionStats'] = _PERPOSSESSIONSTATS

AverageCounts = _reflection.GeneratedProtocolMessageType('AverageCounts', (_message.Message,), dict(
  DESCRIPTOR = _AVERAGECOUNTS,
  __module__ = 'api.stats.per_possession_stats_pb2'
  # @@protoc_insertion_point(class_scope:api.stats.AverageCounts)
  ))
_sym_db.RegisterMessage(AverageCounts)

PerPossessionStats = _reflection.GeneratedProtocolMessageType('PerPossessionStats', (_message.Message,), dict(
  DESCRIPTOR = _PERPOSSESSIONSTATS,
  __module__ = 'api.stats.per_possession_stats_pb2'
  # @@protoc_insertion_point(class_scope:api.stats.PerPossessionStats)
  ))
_sym_db.RegisterMessage(PerPossessionStats)


# @@protoc_insertion_point(module_scope)
