# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/metadata/mutators.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/metadata/mutators.proto',
  package='api.metadata',
  serialized_pb=_b('\n\x1b\x61pi/metadata/mutators.proto\x12\x0c\x61pi.metadata\"Q\n\x08Mutators\x12)\n\tball_type\x18\x01 \x01(\x0e\x32\x16.api.metadata.BallType\x12\x1a\n\x12game_mutator_index\x18\x02 \x01(\x05*M\n\x08\x42\x61llType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01\x12\x0e\n\nBASKETBALL\x10\x02\x12\x08\n\x04PUCK\x10\x03\x12\x0c\n\x08\x43UBEBALL\x10\x04\x12\x0c\n\x08\x42REAKOUT\x10\x05')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_BALLTYPE = _descriptor.EnumDescriptor(
  name='BallType',
  full_name='api.metadata.BallType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BASKETBALL', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUCK', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUBEBALL', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BREAKOUT', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=128,
  serialized_end=205,
)
_sym_db.RegisterEnumDescriptor(_BALLTYPE)

BallType = enum_type_wrapper.EnumTypeWrapper(_BALLTYPE)
DEFAULT = 1
BASKETBALL = 2
PUCK = 3
CUBEBALL = 4
BREAKOUT = 5



_MUTATORS = _descriptor.Descriptor(
  name='Mutators',
  full_name='api.metadata.Mutators',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ball_type', full_name='api.metadata.Mutators.ball_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mutator_index', full_name='api.metadata.Mutators.game_mutator_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=126,
)

_MUTATORS.fields_by_name['ball_type'].enum_type = _BALLTYPE
DESCRIPTOR.message_types_by_name['Mutators'] = _MUTATORS
DESCRIPTOR.enum_types_by_name['BallType'] = _BALLTYPE

Mutators = _reflection.GeneratedProtocolMessageType('Mutators', (_message.Message,), dict(
  DESCRIPTOR = _MUTATORS,
  __module__ = 'api.metadata.mutators_pb2'
  # @@protoc_insertion_point(class_scope:api.metadata.Mutators)
  ))
_sym_db.RegisterMessage(Mutators)


# @@protoc_insertion_point(module_scope)
